@@ -39,10 +39,6 @@ using namespace aff;
 #include <unistd.h>
 #endif
 
-#ifdef HAVE_TERM_H
-#include <term.h>
-#endif
-
 #ifdef WIN32
 #include "unix4win32.h"
 #endif
@@ -371,7 +367,7 @@ int affcopy(char *infile,vector<string> &outfiles)
 	uint32_t arg=0;
 	if(af_get_seg(ain,segname,&arg,segbuf,&seglen)){
 	    unlink_outfiles(outfiles);	// failure; unlink the output files
-	    err(1,"Cannot read segment '%s' in %s. Deleteing output file", segname,af_filename(ain));
+	    err(1,"Cannot read segment '%s' in %s. Deleting output file", segname,af_filename(ain));
 	}
 
 	/* Calculate the MD5 of this segment and remember it in the map */
@@ -469,7 +465,7 @@ int affcopy(char *infile,vector<string> &outfiles)
 	AFFILE *af = afouts.begin()->af;
 	uint64_t w = af->bytes_written;
 	double sec = ((t1.tv_sec-t0.tv_sec)+(t1.tv_usec-t0.tv_usec)/1000000.0);
-	printf("%s: %"I64d" bytes transferred in %.2f seconds. xfer rate: %.2f MBytes/sec\n",
+	printf("%s: %" I64d " bytes transferred in %.2f seconds. xfer rate: %.2f MBytes/sec\n",
 	       af_filename(af),w,sec,(w/1000000.0) / sec);
     }
 	
